@@ -29,6 +29,8 @@ missingData <- function(M) {
   missing_counts <- sapply(cols, function(x){
     sum(is.na(M[,x]) | M[,x] %in% c("NA,0000,NA","NA","","none"))
     })
+  
+  if (sum(as.numeric(M$TC), na.rm=T)==0){missing_counts["TC"]=nrow(M)}
   # calculate the percentage of missing values in each column
   missing_pct <- round(missing_counts/nrow(M) * 100, 2)
   # create a dataframe with the column names, number of missing values and percentage of missing values
@@ -37,13 +39,13 @@ missingData <- function(M) {
   # create a vector with the tags
   tag <- unlist(
     strsplit(
-      "AB,AU,C1,CR,DE,DI,DT,ID,LA,NR,PY,RP,SO,TC,TI,WC",","
+      "AB,AU,C1,CR,DE,DI,DT,ID,LA,PY,RP,SO,TC,TI,WC",","
       )
   )
   # create a vector with the description of the tags
   description <- trimws(unlist(
     strsplit(
-      "Abstract, Author,Affiliation,Cited References,Keywords,DOI,Document Type,Keywords Plus,Language,Number of Cited References,
+      "Abstract, Author,Affiliation,Cited References,Keywords,DOI,Document Type,Keywords Plus,Language,
       Publication Year,Corresponding Author, Journal, Total Citation, Title, Science Categories", ","
     )
   ))
